@@ -25,7 +25,7 @@ try:
         FIELD_TYPE.CHAR: 'CharField',
         FIELD_TYPE.DECIMAL: 'DecimalField',
         FIELD_TYPE.NEWDECIMAL: 'DecimalField',
-        FIELD_TYPE.DATE: 'DateTimeField',
+        FIELD_TYPE.DATE: 'DateField',
         FIELD_TYPE.DATETIME: 'DateTimeField',
         FIELD_TYPE.DOUBLE: 'FloatField',
         FIELD_TYPE.FLOAT: 'FloatField',
@@ -34,6 +34,7 @@ try:
         FIELD_TYPE.LONGLONG: 'BigIntegerField',
         FIELD_TYPE.SHORT: 'IntegerField',
         FIELD_TYPE.STRING: 'CharField',
+        FIELD_TYPE.TIME: 'TimeField',
         FIELD_TYPE.TIMESTAMP: 'DateTimeField',
         FIELD_TYPE.TINY: 'IntegerField',
         FIELD_TYPE.TINY_BLOB: 'TextField',
@@ -56,7 +57,7 @@ class DB(object):
     def get_columns(self, table):
         """
         get_columns('some_table')
-        
+
         {
             'name': 'CharField',
             'age': 'IntegerField',
@@ -67,7 +68,7 @@ class DB(object):
     def get_foreign_keys(self, table):
         """
         get_foreign_keys('some_table')
-        
+
         [
             # column,   rel table,  rel pk
             ('blog_id', 'blog',     'id'),
@@ -100,8 +101,11 @@ class PgDB(DB):
         700: 'FloatField',
         701: 'FloatField',
         1043: 'CharField',
+        1082: 'DateField',
         1114: 'DateTimeField',
         1184: 'DateTimeField',
+        1083: 'TimeField',
+        1266: 'TimeField',
         1700: 'DecimalField',
     }
 
@@ -116,13 +120,13 @@ class PgDB(DB):
         framing = '''
             SELECT
                 kcu.column_name, ccu.table_name, ccu.column_name
-            FROM information_schema.table_constraints AS tc 
-            JOIN information_schema.key_column_usage AS kcu 
+            FROM information_schema.table_constraints AS tc
+            JOIN information_schema.key_column_usage AS kcu
                 ON tc.constraint_name = kcu.constraint_name
-            JOIN information_schema.constraint_column_usage AS ccu 
+            JOIN information_schema.constraint_column_usage AS ccu
                 ON ccu.constraint_name = tc.constraint_name
-            WHERE 
-                tc.constraint_type = 'FOREIGN KEY' AND 
+            WHERE
+                tc.constraint_type = 'FOREIGN KEY' AND
                 tc.table_name = %s
         '''
         fks = []
@@ -134,14 +138,14 @@ class PgDB(DB):
 class MySQLDB(DB):
     # thanks, django
     reverse_mapping = MYSQL_MAP
-    
+
     def get_conn_class(self):
         return MySQLDatabase
-    
+
     def get_columns(self, table):
         curs = self.conn.execute('select * from %s limit 1' % table)
         return dict((r[0], self.reverse_mapping.get(r[1], 'UnknownFieldType')) for r in curs.description)
-    
+
     def get_foreign_keys(self, table):
         framing = '''
             SELECT column_name, referenced_table_name, referenced_column_name
@@ -170,13 +174,14 @@ class SqDB(DB):
         'real': 'FloatField',
         'text': 'TextField',
         'char': 'CharField',
-        'date': 'DateTimeField',
+        'date': 'DateField',
         'datetime': 'DateTimeField',
+        'time': 'TimeField',
     }
-    
+
     def get_conn_class(self):
         return SqliteDatabase
-    
+
     def map_col(self, col):
         col = col.lower()
         if col in self.reverse_mapping:
@@ -203,7 +208,7 @@ class SqDB(DB):
 
         curs = self.conn.execute("SELECT sql FROM sqlite_master WHERE tbl_name = ? AND type = ?", [table, "table"])
         table_def = curs.fetchone()[0].strip()
-        
+
         try:
             columns = re.search('\((.+)\)', table_def).groups()[0]
         except AttributeError:
@@ -218,7 +223,7 @@ class SqDB(DB):
 
             fk_column, rel_table, rel_pk = [s.strip('"') for s in m.groups()]
             fks.append((fk_column, rel_table, rel_pk))
-        
+
         return fks
 
 
@@ -251,7 +256,7 @@ def get_db(engine):
 def introspect(engine, database, **connect):
     db = get_db(engine)
     db.connect(database, **connect)
-    
+
     tables = db.get_tables()
 
     models = {}
@@ -301,7 +306,7 @@ def introspect(engine, database, **connect):
             ])
             print '    %s = %s(%s)' % (cn(column), field_class, field_params)
         print
-        
+
         print '    class Meta:'
         print '        db_table = \'%s\'' % model
         print
